@@ -5,7 +5,7 @@ import threading
 import gi
 gi.require_version("Gtk", "3.0")
 
-from gi.repository import Gtk,GdkPixbuf,GObject,Pango,Gdk,Gio
+from gi.repository import Gtk,GdkPixbuf,GObject,Pango,Gdk,Gio,GLib
 from gettext import gettext as _
 from gettext import ngettext
 
@@ -141,7 +141,7 @@ class UI:
                 self.quit = False
 
         # Generate puzzles in background...
-        GObject.timeout_add_seconds(1, lambda *args: self.start_worker_thread() and True)
+        GLib.timeout_add_seconds(1, lambda *args: self.start_worker_thread() and True)
 
     @inactivate_new_game_etc
     def select_game (self):
@@ -276,7 +276,7 @@ class UI:
             self.gsd.set_bg_color(bgcol)
 
     def setup_autosave (self):
-        GObject.timeout_add_seconds(self.settings.get_int('auto-save-interval') or 60, # in seconds...
+        GLib.timeout_add_seconds(self.settings.get_int('auto-save-interval') or 60, # in seconds...
                             self.autosave)
 
     def setup_main_boxes (self):
@@ -531,11 +531,11 @@ class UI:
         '''
         self.cleared_notes.append((self.tinfo.current_tracker, self.gsd.clear_notes(side)))
         # Turn off auto-hint if the player clears the bottom notes
-        if side == 'Bottom' and self.settings.get_boolean('always-show-hints'):
+        if side == 'Bottom' and self.settings.get_boolean('always_show_hints'):
             always_show_hint_wdgt = self.main_actions.get_action('AlwaysShowPossible')
             always_show_hint_wdgt.activate()
         # Update the hints...in case we're redoing a clear of them
-        if self.settings.get_boolean ('always-show-hints'):
+        if self.settings.get_boolean ('always_show_hints'):
             self.gsd.update_all_hints()
 
     def undo_clear_notes(self):
@@ -684,7 +684,7 @@ class UI:
 
     @simple_debug
     def print_multiple_games (self, *args):
-        gp = printing.GamePrinter(self.sudoku_maker)
+        gp = printing.GamePrinter(self.sudoku_maker, self.w)
         gp.run_dialog()
 
 class TrackerBox (Gtk.VBox):
